@@ -81,6 +81,20 @@ def get(args):
             break
     remove_overlay(args)
 
+def validate(args, channel, image_zip):
+    # Verify that the zip comes from the channel
+    cfg = tools.config.load(args)
+    channel_url = cfg["waydroid"][channel]
+    channel_request = helpers.http.retrieve(channel_url)
+    if channel_request[0] != 200:
+        return False
+    channel_responses = json.loads(channel_request[1].decode('utf8'))["response"]
+    for build in channel_responses:
+        if sha256sum(image_zip) == build['id']:
+            return True
+    logging.warning(f"Could not verify the image {image_zip} against {channel_url}")
+    return False
+
 def replace(args, system_zip, system_time, vendor_zip, vendor_time):
     cfg = tools.config.load(args)
     args.images_path = cfg["waydroid"]["images_path"]
@@ -122,10 +136,10 @@ def make_prop(args, cfg, full_props_path):
     add_prop("waydroid.host.uid", "user_id")
     add_prop("waydroid.host.gid", "group_id")
     add_prop("waydroid.host_data_path", "waydroid_data")
-    add_prop("waydroid.xdg_runtime_dir", "xdg_runtime_dir")
-    add_prop("waydroid.pulse_runtime_path", "pulse_runtime_path")
-    add_prop("waydroid.wayland_display", "wayland_display")
     add_prop("waydroid.background_start", "background_start")
+    props.append("waydroid.xdg_runtime_dir=" + tools.config.defaults["container_xdg_runtime_dir"])
+    props.append("waydroid.pulse_runtime_path=" + tools.config.defaults["container_pulse_runtime_path"])
+    props.append("waydroid.wayland_display=" + tools.config.defaults["container_wayland_display"])
     if which("waydroid-sensord") is None:
         props.append("waydroid.stub_sensors_hal=1")
     dpi = cfg["lcd_density"]
